import React, { useEffect, useRef, useState } from "react";
import {
  CarouselProvider,
  Slider,
  Slide,
  ButtonBack,
  ButtonNext,
} from "pure-react-carousel";
import Modal from "react-modal";
import "pure-react-carousel/dist/react-carousel.es.css";
import { useSelector } from "react-redux";
import { Container, SlideIdicator, Close } from "./styles";
import styled from "styled-components";
import { useMediaQuery } from "react-responsive";
import Image from "next/image";

Modal.setAppElement("#__next");

function StorySlider(props) {
  const slideRef = useRef(null);
  const [currentSlide, setCurrentSlide] = useState(0);
  const storiesData = useSelector((state) => state?.home?.stories);
  const [storyHeight, setSH] = useState(500);
  const [stop, setStop] = useState(false);

  useEffect(() => {
    setSH(window.innerHeight - 40);
  }, []);

  const handleEnd = () => {
    setCurrentSlide(slideRef?.current?.state?.currentSlide);
  };

  const onClickStart = (e) => {
    setStop(true);
    e.stopPropagation();
  };
  const onClickEnd = (e) => {
    setStop(false);
    e.stopPropagation();
  };

  return (
    <Container>
      <div
        style={{
          display: "flex",
          alignItems: "center",
          justifyContent: "space-around",
          width: "100%",
          height: 20,
          zIndex: 3,
          position: "relative",
        }}
      >
        {storiesData?.map((_, ind) => {
          return (
            <SlideIdicator
              key={ind}
              selected={currentSlide === ind ? true : false}
              width={"100%" - 5}
            >
              {ind === currentSlide && (
                <div
                  style={{
                    animationPlayState: stop ? "paused" : "running",
                  }}
                />
              )}
            </SlideIdicator>
          );
        })}
      </div>
      <CarouselProvider
        naturalSlideWidth={350}
        naturalSlideHeight={storyHeight}
        totalSlides={storiesData.length}
        isPlaying={!stop}
        interval={3000}
        infinite
        dragEnabled={false}
        touchEnabled={false}
      >
        <Close onClick={() => props.closeModal()}>
          <img src={"/assets/images/closeWhite.svg"} alt="close" />
        </Close>
        <Slider
          ref={slideRef}
          style={{
            position: "relative",
            height: "100%",
            marginTop: -20,
          }}
          onTransitionEnd={handleEnd}
        >
          {storiesData?.map((val, ind) => {
            return (
              <Slide
                onClick={(e) => {
                  e.stopPropagation();
                }}
                onMouseDown={onClickStart}
                onMouseUp={onClickEnd}
                onTouchStart={onClickStart}
                onTouchEnd={onClickEnd}
                key={ind}
                index={ind}
              >
                <div style={{ height: "100%", position: "relative" }}>
                  {/* <img
                    src={val?.acf?.image}
                    alt="image"
                    className="slide-image"
                  /> */}
                  <Image
                    src={val?.acf?.image}
                    className="slide-image"
                    alt="image"
                    fill
                    style={{
                      objectFit: "cover",
                      top: "50%",
                      left: "50%",
                    }}
                  />
                  <div style={{ width: "100%", height: "50%" }} />
                  <div className="slide-text">
                    <h3>{val?.acf?.title}</h3>
                    <p style={{ fontWeight: "200" }}>{val?.acf?.description}</p>
                  </div>
                </div>
              </Slide>
            );
          })}
        </Slider>
        <div
          style={{
            position: "absolute",
            zIndex: 99,
            width: "100%",
            top: "50%",
          }}
        >
          <ButtonBack
            className="slider-arrows"
            id="ButtonBack"
            onClick={(e) => {
              e.stopPropagation();
              setCurrentSlide(slideRef?.current?.state.currentSlide - 1);
              setStop(true);
              setTimeout(() => {
                setStop(false);
              }, 200);
            }}
          >
            <img
              src="/assets/images/chevdown.svg"
              style={{
                transform: "rotate(45deg)",
                width: 15,
              }}
              alt="back"
            />
          </ButtonBack>
          <ButtonNext
            className="slider-arrows"
            id="ButtonNext"
            onClick={(e) => {
              e.stopPropagation();
              setCurrentSlide(slideRef?.current?.state?.currentSlide + 1);
              setStop(true);
              setTimeout(() => {
                setStop(false);
              }, 200);
            }}
          >
            <img
              src="/assets/images/chevdown.svg"
              style={{
                transform: "rotate(-45deg)",
                width: 15,
              }}
              alt="back"
            />
          </ButtonNext>
        </div>
      </CarouselProvider>
    </Container>
  );
}
const customStyles = {
  content: {
    top: "50%",
    left: "50%",
    right: "auto",
    bottom: "auto",
    marginRight: "-50%",
    transform: "translate(-50%, -50%)",
    background: "#00000085",
    width: "100%",
    height: "100%",
  },
  overlay: {
    background: "transparent",
  },
};

const Close2 = styled.div`
  position: absolute;
  top: 50px;
  right: 50%;
  background-color: #e13219;
  transition: 0.3s;
  transform: translateX(250px) rotate(45deg);
  width: 55px;
  height: 55px;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  & img {
    transform: rotate(-45deg);
    transition: 0.3s;
  }
  &:hover {
    transform: translateX(250px) rotate(0deg);
  }
  &:hover img {
    transform: rotate(0deg);
  }
  @media (max-width: 768px) {
    display: none;
  }
`;

const StoryModal = ({ closeModal, modalIsOpen }) => {
  const isMobileNew = useMediaQuery({
    query: "(max-width: 600px)",
  });
  useEffect(() => {
    document.addEventListener("click", closeModal);
    return () => document.addEventListener("click", closeModal);
  });

  return (
    <Modal
      isOpen={modalIsOpen}
      onRequestClose={closeModal}
      style={customStyles}
      contentLabel="Story"
      closeTimeoutMS={700}
    >
      <Close2 onClick={closeModal}>
        <img src={"/assets/images/closeWhite.svg"} alt="close" />
      </Close2>

      <div
        style={{
          width: isMobileNew ? "100%" : 350,
          height: "100%",
          backgroundColor: "lightgrey",
          margin: "0 auto",
          marginTop: 0,
        }}
      >
        <StorySlider isMobile={false} closeModal={() => closeModal()} />
      </div>
    </Modal>
  );
};
export default StoryModal;
