import { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import s from "../style/index.module.sass";
import parse from "html-react-parser";
import { getBrandsByCategory } from "../../../../redux/actions/homeActions";
import Image from "next/image";
import Link from "next/link";
import { getProductsByBrandsCats } from "../../../../redux/actions/productActions";
import { useRouter } from "next/router";
import imageMegamenuProduits from "../../../../public/assets/images/image-megamenu-produits.png";

export default function MegaMenu({ close }) {
  const [swipeTo, setSwipe] = useState(0);
  const [marque, setMarque] = useState();

  const categories = useSelector((state) => state?.product?.productsCats);
  const brands = useSelector((state) => state?.home?.brandsByCat);
  const dispatch = useDispatch();

  const superCat = categories?.filter(
    (val) => val?.parent === 0 && val.name !== "Uncategorized",
  );
  const [selectedSuperCat, setSuperCat] = useState(
    superCat && superCat[0] ? superCat[0] : null,
  );

  const subCat = categories?.filter(
    (item) => item.parent === selectedSuperCat?.id,
  );
  const [selectedSubCat, setSubCat] = useState(
    subCat && subCat[0] ? subCat[0] : null,
  );

  useEffect(() => {
    selectedSubCat && dispatch(getBrandsByCategory(selectedSubCat.id));
  }, [dispatch, selectedSubCat]);

  useEffect(() => {
    subCat && setSubCat(subCat[0]);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [selectedSuperCat]);

  return (
    <div
      className={s.megaMenu}
      style={
        window && window.innerWidth < 660
          ? { transform: `translateX(${swipeTo * -100}vw)` }
          : null
      }
    >
      <img
        onClick={() => close(false)}
        className={s.close}
        src="/assets/images/close.svg"
        alt="close"
      />

      <Col3 marque={marque} subCatId={selectedSubCat?.id} />
      <Col2
        marque={marque}
        setMarque={setMarque}
        slug={selectedSuperCat?.slug}
        pre={selectedSubCat}
        swipe={setSwipe}
        items={brands}
      />

      <Col1
        pre={selectedSuperCat}
        swipe={setSwipe}
        supCat={selectedSuperCat ? selectedSuperCat.name : ""}
        items={subCat}
        setSelect={setSubCat}
        selected={selectedSubCat}
      />

      <Col0
        close={() => close(false)}
        swipe={setSwipe}
        setSelect={setSuperCat}
        items={superCat}
        selected={selectedSuperCat}
      />
    </div>
  );
}

const Col0 = ({ items, selected, setSelect, swipe, close }) => {
  const clickHandler = (e) => {
    setSelect(e);
    swipe(1);
  };

  return (
    <div className={`${s.col_0} ${s.col}`}>
      <div onClick={close} className={s.backBtn}>
        <Image
          alt="retour"
          src="/assets/images/yellowarrow.svg"
          width={28}
          height={28}
        />
        Retour
      </div>
      {/* <img alt="category" src="/assets/images/categorybg.jpg" /> */}
      {/* <img alt="category" src="/assets/images/image-megamenu-produits.png" /> */}
      <Image alt="category" src={imageMegamenuProduits} />
      <ul className={s.redLayout}>
        {items
          .sort((a, b) => (a.name < b.name ? -1 : a.name > b.name ? 1 : 0))
          ?.map((e, i) => (
            <li
              onClick={() => clickHandler(e)}
              key={i}
              className={e.id === selected.id ? s.act : ""}
            >
              {parse(e.name || "")}
            </li>
          ))}
        <Link href={`/${selected?.slug}`}>
          <div className={`${s.lookMore} `}>
            <span>
              <Link href="/produits" className={s.allProducts}>
                DÉCOUVRIR TOUS NOS PRODUITS
              </Link>
              Voir produits {selected ? parse(selected?.name) : ""}
            </span>
            <Image
              src="/assets/images/yellowarrow.svg"
              width={24}
              height={24}
            />
          </div>
        </Link>
      </ul>
    </div>
  );
};

const Col1 = ({ items, selected, setSelect, supCat, swipe, pre }) => {
  const [openList, setOpen] = useState(true);

  useEffect(() => {
    setOpen(true);
  }, [selected]);

  const clickHandler = (e) => {
    setSelect(e);
    setOpen((e) => !e);
  };

  const chevronClick = (e) => {
    e.stopPropagation();
    setOpen((e) => !e);
  };
  const url = `/${pre?.slug}/${selected?.slug}`;
  return (
    <div className={`${s.col_1} ${s.col}`}>
      <div onClick={() => swipe((e) => --e)} className={s.backBtn}>
        <Image
          alt="icon"
          src="/assets/images/redarrow.svg"
          width={28}
          height={28}
        />
        Retour
      </div>
      <span className={s.title}>{parse(supCat)}</span>

      <ul className={s.ulLevel1}>
        {items
          .sort((a, b) => (a.name < b.name ? -1 : a.name > b.name ? 1 : 0))
          ?.map((e, i) => (
            <li key={i} className={selected.id === e.id ? s.act : ""}>
              <span onClick={() => clickHandler(e)} className={s.listTitle}>
                <span onClick={chevronClick} className={s.chevron} />
                {parse(e.name)}
              </span>
              <UlLastLevel
                open={selected.id === e.id && openList}
                items={e?.sub_cats}
                onClick={() => swipe(2)}
                pre={url}
              />
            </li>
          ))}
      </ul>

      <Link href={url}>
        <div className={`${s.lookMore} `}>
          <span>Voir produits {parse(selected?.name || "")}</span>
          <Image src="/assets/images/redarrow.svg" width={24} height={24} />
        </div>
      </Link>
    </div>
  );
};

const Col2 = ({ items, swipe, setMarque, marque }) => {
  const loadingBrands = useSelector((state) => state?.home?.brandsByCatLoading);
  const { push } = useRouter();
  useEffect(() => {
    if (items?.length) setMarque({});
  }, [items]);
  const handelClick = (e) => () =>
    window.innerWidth < 768 ? push(`/marques/${e?.slug}`) : setMarque(e);

  return (
    <div className={`${s.col_2} ${s.col}`}>
      <div onClick={() => swipe((e) => --e)} className={s.backBtn}>
        <Image src="/assets/images/redarrow.svg" width={28} height={28} />
        Retour
      </div>
      <span className={s.title}>Marques</span>
      <ul className={s.marquesUl}>
        {loadingBrands ? (
          <div className={s.loader}></div>
        ) : (
          items
            ?.filter((e) => e.parent == 0)
            .sort((a, b) => (a.name < b.name ? -1 : a.name > b.name ? 1 : 0))
            ?.map((e) => (
              <li
                className={marque?.slug === e?.slug ? s.act : ""}
                onClick={handelClick(e)}
                key={e.slug}
              >
                {e.name}
              </li>
            ))
        )}
      </ul>
      {marque?.name && (
        <Link href={`/marques/${marque?.slug}`}>
          <div className={`${s.lookMore} `}>
            <span>Voir marque {parse(marque?.name || "")}</span>
            <Image src="/assets/images/redarrow.svg" width={24} height={24} />
          </div>
        </Link>
      )}
    </div>
  );
};

const Col3 = ({ marque, subCatId }) => {
  const dispatch = useDispatch();
  const brands = useSelector((state) => state.home?.brands);
  const products =
    useSelector((state) => state?.product?.allProductsList) || [];
  const brand = brands?.find((e) => e.slug == marque?.slug);
  const brandImage = brand?.acf.image;
  useEffect(() => {
    dispatch(getProductsByBrandsCats(subCatId, marque?.slug || ""));
  }, [marque, subCatId]);
  const product = products?.find((e) => e.featured) || products[0];
  const type = product?.meta_data?.find((e) => e.key === "type")?.value;
  const tag =
    product?.categories.find(
      (e, i, arr) => !arr.find((b) => b.parent === e.term_id),
    )?.name || "";
  const quantite = product?.meta_data?.find((e) => e.key === "quantite")?.value;
  return (
    <div className={`${s.col_3} ${s.col}`}>
      {product?.images[0].src && (
        <Link href={`/produits/${product?.slug}`}>
          {/* <img
            className={s.productImg}
            alt="product"
            src={product?.images[0].src}
          /> */}
          <Image
            alt="product"
            src={product?.images[0].src}
            className={s.productImg}
            width={300}
            height={280}
            style={{
              objectFit: "contain",
            }}
          />
          {brandImage && (
            <Image alt="brand" src={brandImage} width={130} height={40} />
          )}
          <span className={s.productName}>{product?.name}</span>
          <span>{type}</span>
          <span>{tag}</span>
          <span>{quantite}</span>
        </Link>
      )}
      {product?.name && brand && (
        <Link href={`/produits/${product?.slug}`}>
          <div className={`${s.lookMore} `}>
            <span>Voir produit {product?.name}</span>
            <Image
              alt="arrow"
              src="/assets/images/redarrow.svg"
              height={24}
              width={24}
              style={{
                objectFit: "contain",
              }}
            />
          </div>
        </Link>
      )}
    </div>
  );
};

const UlLastLevel = ({ items, open, pre, onClick }) => (
  <ul className={`${s.lastLevel} ${open ? s.openList : ""}`}>
    {items
      ?.filter((e) => e.count !== 0)
      .map((e, i) => (
        <li key={i}>
          <Link href={`${pre}/${e.slug}`}>{e.name}</Link>
        </li>
      ))}
    <li>
      <a onClick={onClick}>Découvrir les marques </a>
    </li>
  </ul>
);
