import Link from "next/link";
import { useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import styled from "styled-components";
import { getGroupePage } from "../../../../redux/actions/homeActions";

export default function StyledMenu({ menu, setShowSM }) {
  const dispatch = useDispatch();

  const data = useSelector(
    (state) => state?.home[menu == 1 ? "mm_about" : "mm_carriere"],
  );
  // const mm_about = useSelector((state) => state?.home?.mm_about);
  const cards = data && [data["box_1"], data["box_2"], data["box_3"]];
  useEffect(() => {
    dispatch(getGroupePage());
  }, []);
  const close = () => {
    setShowSM && setShowSM(-1);
  };
  return (
    <StyledMenuS menu={menu} onClick={(e) => e.stopPropagation()}>
      <div onClick={close} className="closeIcon" />
      <div className="mainImg">
        <h2>Magpharm Laboratoires</h2>
        <span>
          {menu === 1 ? "Ravivez votre nature" : "Le miracle de faire renaître"}
        </span>
        <p>
          {menu == 1
            ? "20 ans de savoir en phytothérapie, acteur principal de la dermo-cosmétique en Algérie."
            : "Découvrez le groupe Magpharm, sa vision, ses missions et valeurs…"}
        </p>
      </div>

      <div className="cards">
        {cards?.map((e, i) => (
          <Link legacyBehavior key={i} href={e?.lien?.url}>
            <a className="card">
              <img src={e.image.url} alt="card" />
              <div>
                <div>
                  <h3>{e.titre}</h3>
                  <p>{e.description}</p>
                </div>
                <Link href={e?.lien?.url}>{e.lien.title}</Link>
              </div>
            </a>
          </Link>
        ))}
      </div>
    </StyledMenuS>
  );
}
const StyledMenuS = styled.div`
  height: calc(100vh - 80px);
  height: -webkit-fill-available;
  width: 100vw;
  background-color: white;
  position: fixed;
  left: 0;
  top: 80px;
  display: flex;
  flex-flow: row nowrap;
  z-index: 18;
  .closeIcon {
    cursor: pointer;
    position: absolute;
    right: 16px;
    top: 0;
    padding: 16px;
    z-index: 4;
    background-image: url("/assets/images/close.svg");
    background-repeat: no-repeat;
    background-position: center;
  }

  .mainImg {
    /* background-image: url("./assets/images/imagesPlaceHolders/Screen Shot 202.png"); */
    background-image: url(${({ menu }) =>
      menu === 2
        ? "'./assets/images/imagesPlaceHolders/mateus-campos-f.png'"
        : "'./assets/images/imagesPlaceHolders/Screen Shot 202.png'"});
    background-color: red;
    background-position: center;
    background-repeat: no-repeat;
    background-size: cover;
    height: 100%;
    width: 30%;
    position: relative;
    color: #f5f5f5;
    text-align: center;
    display: flex;
    justify-content: center;
    align-items: center;
    flex-direction: column;
    padding: 24px;
    font-weight: 600;
  }
  .mainImg h2 {
    font-weight: 500;
    padding-bottom: 12px;
    font-size: 28px;
  }
  .mainImg h2::before,
  .mainImg h2::after {
    content: "";
    background-color: white;
    display: inline-block;
    left: 50%;
    transform: translateX(-50%);
    position: absolute;
  }
  .mainImg h2::before {
    height: 8px;
    width: 8px;
    top: 100%;
    transform: translate(-50%, -50%) rotate(45deg);
  }

  .mainImg h2::after {
    width: 50px;
    height: 1px;
    top: 100%;
  }
  .mainImg > * {
    position: relative;
    z-index: 2;
  }
  .cards {
    flex-grow: 1;
    width: 70%;
    display: flex;
    flex-flow: row nowrap;
    background-color: #f5f5f5;
  }
  .card h3:before {
    content: "";
    display: inline-block;
    height: 14px;
    width: 14px;
    background-color: #e13219;
    transform: rotate(45deg);
    margin-right: 10px;
  }
  .card a {
    color: #98989a;
    text-transform: uppercase;
  }
  .card a:after {
    content: "";
    background-image: url("/assets/images/redarrow.svg");
    height: 24px;
    width: 30px;
    display: inline-block;
    background-repeat: no-repeat;
    background-position: center bottom;
    margin-left: 12px;
  }
  .card p {
    color: #505257;
    line-height: 1.4;
    margin-top: 4px;
    margin-bottom: 0;
    text-overflow: ellipsis;
    display: -webkit-box;
    -webkit-line-clamp: 5;
    -webkit-box-orient: vertical;
    overflow: hidden;
  }
  .card h3 {
    color: #e13219;
    font-size: 22px;
    height: 56px;
    margin-bottom: 0px;
  }
  .card img {
    display: block;
    aspect-ratio: 5/4;
    object-fit: cover;
    margin-top: 16px;
    width: 100%;
  }
  .card:nth-of-type(2) {
    border-inline: 1px solid #ddd9;
  }
  .card {
    background-color: #f5f5f5;
    height: 100%;
    width: 33.3%;
    padding: 32px;
    display: flex;
    flex-direction: column;
  }
  .card > div {
    display: flex;
    flex-direction: column;
    flex-grow: 1;
    justify-content: space-between;
    max-height: 240px;
  }
  .mainImg::after {
    background-color: #ff4b35d8;
    content: "";
    width: 100%;
    height: 100%;
    display: inline-block;
    position: absolute;
    top: 0;
    left: 0;
  }
  .mainImg::before {
    background-image: url("/assets/images/video-bg.svg");
    content: "";
    width: 100%;
    height: 100%;
    display: inline-block;
    position: absolute;
    top: 0;
    left: 0;
    z-index: 3;
    background-size: contain;
    background-position: bottom center;
    background-repeat: no-repeat;
  }
  @media (max-width: 1020px) {
    .mainImg {
      padding: 10px;
    }
    .card {
      padding: 16px;
    }
    .card h3:before {
      width: 10px;
      height: 10px;
    }
    .card h3 {
      font-size: 18px;
    }
    .card a {
      font-size: 13px;
    }
  }
  @media (max-width: 750px) {
    flex-direction: column;
    overflow-y: scroll;
    .closeIcon {
      background-image: url("/assets/images/closeWhite.svg");
    }
    .mainImg {
      width: 100%;
      height: 240px;
      background-position: center 30%;
    }
    .cards {
      width: 100%;
    }
  }
  @media (max-width: 929px) and (min-width: 660px) {
    height: calc(100vh - 102px);
    top: 102px;
  }
  @media (max-width: 570px) {
    .cards {
      flex-direction: column;
      padding-bottom: 32px;
    }
    .card img {
      height: 100%;
      width: 100%;
    }
    .card h3 {
      font-size: 16px;
      height: unset;
    }
    .card p {
      font-size: 13px;
    }
    .card {
      width: 100%;
      display: grid;
      grid: auto / 35% 65%;
      gap: 16px;
    }
    .card > div {
      padding-top: 8px;
      padding-right: 16px;
      display: block;
    }
  }
`;
