
const NextServer = require('next/dist/server/next-server').default
const http = require('http')
const path = require('path')
process.env.NODE_ENV = 'production'
process.chdir(__dirname)

// Make sure commands gracefully respect termination signals (e.g. from Docker)
// Allow the graceful termination to be manually configurable
if (!process.env.NEXT_MANUAL_SIG_HANDLE) {
  process.on('SIGTERM', () => process.exit(0))
  process.on('SIGINT', () => process.exit(0))
}

let handler

const server = http.createServer(async (req, res) => {
  try {
    await handler(req, res)
  } catch (err) {
    console.error(err);
    res.statusCode = 500
    res.end('internal server error')
  }
})
const currentPort = parseInt(process.env.PORT, 10) || 3000
const hostname = process.env.HOSTNAME || 'localhost'

server.listen(currentPort, (err) => {
  if (err) {
    console.error("Failed to start server", err)
    process.exit(1)
  }
  const nextServer = new NextServer({
    hostname,
    port: currentPort,
    dir: path.join(__dirname),
    dev: false,
    customServer: false,
    conf: {"env":{},"webpack":null,"eslint":{"ignoreDuringBuilds":true},"typescript":{"ignoreBuildErrors":false,"tsconfigPath":"tsconfig.json"},"distDir":"./.next","cleanDistDir":true,"assetPrefix":"","configOrigin":"next.config.js","useFileSystemPublicRoutes":true,"generateEtags":true,"pageExtensions":["tsx","ts","jsx","js"],"target":"server","poweredByHeader":true,"compress":true,"analyticsId":"","images":{"deviceSizes":[640,750,828,1080,1200,1920,2048,3840],"imageSizes":[16,32,48,64,96,128,256,384],"path":"/_next/image","loader":"default","loaderFile":"","domains":["dashboard.magpharm.com"],"disableStaticImages":false,"minimumCacheTTL":60,"formats":["image/webp"],"dangerouslyAllowSVG":false,"contentSecurityPolicy":"default-src 'self'; script-src 'none'; sandbox;","contentDispositionType":"inline","remotePatterns":[],"unoptimized":false},"devIndicators":{"buildActivity":true,"buildActivityPosition":"bottom-right"},"onDemandEntries":{"maxInactiveAge":15000,"pagesBufferLength":2},"amp":{"canonicalBase":""},"basePath":"","sassOptions":{},"trailingSlash":false,"i18n":null,"productionBrowserSourceMaps":false,"optimizeFonts":true,"excludeDefaultMomentLocales":true,"serverRuntimeConfig":{},"publicRuntimeConfig":{},"reactStrictMode":true,"httpAgentOptions":{"keepAlive":true},"outputFileTracing":true,"staticPageGenerationTimeout":60,"swcMinify":true,"output":"standalone","experimental":{"clientRouterFilter":false,"clientRouterFilterRedirects":false,"preCompiledNextServer":false,"fetchCacheKeyPrefix":"","middlewarePrefetch":"flexible","optimisticClientCache":true,"manualClientBasePath":false,"legacyBrowsers":false,"newNextLinkBehavior":true,"cpus":7,"sharedPool":true,"isrFlushToDisk":true,"workerThreads":false,"pageEnv":false,"optimizeCss":false,"nextScriptWorkers":false,"scrollRestoration":false,"externalDir":false,"disableOptimizedLoading":false,"gzipSize":true,"swcFileReading":true,"craCompat":false,"esmExternals":true,"appDir":false,"isrMemoryCacheSize":52428800,"fullySpecified":false,"outputFileTracingRoot":"/Users/mohssineoussama/Work/Magpharm/magpharm","swcTraceProfiling":false,"forceSwcTransforms":false,"largePageDataBytes":128000,"enableUndici":false,"adjustFontFallbacks":false,"adjustFontFallbacksWithSizeAdjust":false,"typedRoutes":false,"instrumentationHook":false,"trustHostHeader":false},"configFileName":"next.config.js","compiler":{"styledComponents":true},"_originalRedirects":[{"source":"/qui-sommes-nous-","destination":"/notre-groupe","permanent":true},{"source":"/gammes/contact.html","destination":"/marques","permanent":true},{"source":"/engagement-qualite","destination":"/developpement-durable","permanent":true},{"source":"/gammes","destination":"/marques","permanent":true},{"source":"/category/actualite","destination":"/le-mag","permanent":true},{"source":"/category/presse","destination":"/le-mag","permanent":true},{"source":"/contact.html","destination":"/contact","permanent":true},{"source":"/portfolio-category/premiers-soins/login.html","destination":"/ou-acheter","permanent":true},{"source":"/gammes/phytencia","destination":"/marques/phytencia","permanent":true},{"source":"/gammes/novalac","destination":"/marques/novalac","permanent":true},{"source":"/gammes/onagrine","destination":"/marques/onagrine","permanent":true},{"source":"/gammes/lca","destination":"/marques/lca-pharma","permanent":true},{"source":"/gammes/seco","destination":"/marques/seco","permanent":true},{"source":"/gammes/alliance","destination":"/marques/alliance","permanent":true},{"source":"/gammes/solyne","destination":"/marques/solyne","permanent":true},{"source":"/gammes/sante-vie","destination":"/marques/sante-vie","permanent":true},{"source":"/gammes/topicrem","destination":"/marques","permanent":true},{"source":"/gammes/phytopharm","destination":"/marques/topicrem","permanent":true},{"source":"/gammes/fgx-international","destination":"/marques","permanent":true},{"source":"/gammes/eau-thermale-avene","destination":"/marques","permanent":true},{"source":"/gammes/noreva","destination":"/marques/noreva","permanent":true},{"source":"/gammes/fillmed","destination":"/marques/fillmed","permanent":true},{"source":"/gammes/mediflex","destination":"/marques/mediflex","permanent":true},{"source":"/gammes/alliance/login.html","destination":"/marques/alliance","permanent":true},{"source":"/gammes/topicrem/contact.html","destination":"/marques/topicrem","permanent":true},{"source":"/gammes/phytencia/login.html","destination":"/marques/phytencia","permanent":true},{"source":"/gammes/phytopharm/contact.html","destination":"/marques/phytopharm","permanent":true},{"source":"/gammes/lca/login.html","destination":"/marques/lca-pharma","permanent":true},{"source":"/gammes/alliance/contact.html","destination":"/marques/alliance","permanent":true},{"source":"/gammes/seco/contact.html","destination":"/marques/seco","permanent":true},{"source":"/gammes/solyne/contact.html","destination":"/marques/solyne","permanent":true},{"source":"/gammes/sante-vie/login.html","destination":"/marques/sante-vie","permanent":true},{"source":"/gammes/sante-vie/contact.html","destination":"/marques/sante-vie","permanent":true},{"source":"/gammes/phytopharm/login.html","destination":"/marques/phytopharm","permanent":true},{"source":"/gammes/seco/login.html","destination":"/marques/seco","permanent":true},{"source":"/gammes/lca/contact.html","destination":"/marques/lca","permanent":true},{"source":"/gammes/topicrem/login.html","destination":"/marques/topicrem","permanent":true},{"source":"/gammes/solyne/login.html","destination":"/marques/solyne","permanent":true},{"source":"/gammes/phytencia/contact.html","destination":"/marques/phytencia","permanent":true},{"source":"/gammes/onagrine/contact.html","destination":"/marques/onagrine","permanent":true},{"source":"/gammes/fgx-international/login.html","destination":"/marques","permanent":true},{"source":"/gammes/onagrine/login.html","destination":"/marques/onagrine","permanent":true},{"source":"/gammes/novalac/login.html","destination":"/marques/novalac","permanent":true},{"source":"/gammes/fgx-international/contact.html","destination":"/marques","permanent":true},{"source":"/gammes/index.php","destination":"/marques","permanent":true},{"source":"/gammes/novalac/contact.html","destination":"/marques/novalac","permanent":true},{"source":"/portfolio-category/sante","destination":"/sante-bien-etre","permanent":true},{"source":"/portfolio-subcategory/douleurs","destination":"/sante-bien-etre/reduire-ses-douleurs","permanent":true},{"source":"/portfolio-category/premiers-soins","destination":"/sante-bien-etre/reduire-ses-douleurs/premiers-soins","permanent":true},{"source":"/portfolio-subcategory/hemorroides","destination":"/sante-bien-etre/reduire-ses-douleurs/mauvaise-circulation-sanguine-hemorroides","permanent":true},{"source":"/portfolio-subcategory/fatigue-et-energie","destination":"/sante-bien-etre/bien-etre","permanent":true},{"source":"/portfolio-subcategory/rhume-grippe","destination":"/sante-bien-etre/traiter-ses-maux-dhiver/rhume-grippe","permanent":true},{"source":"/portfolio-subcategory/vitamines-et-mineraux","destination":"/sante-bien-etre/bien-etre/vitamines-et-mineraux","permanent":true},{"source":"/portfolio-subcategory/fatigue-et-energie","destination":"/sante-bien-etre/bien-etre/stress-fatigue","permanent":true},{"source":"/portfolio-subcategory/sommeil-et-detente","destination":"/sante-bien-etre/bien-etre/troubles-du-sommeil-et-reveil-nocturne","permanent":true},{"source":"/portfolio-subcategory/sante-de-la-femme","destination":"/sante-bien-etre/sante-bien-etre-de-la-femme","permanent":true},{"source":"/portfolio-subcategory/sante-de-l-enfant","destination":"/sante-bien-etre/mon-enfant","permanent":true},{"source":"/portfolio-subcategory/soins-essentiels","destination":"/soins-beaute","permanent":true},{"source":"/portfolio-category/hygiene-et-beaute","destination":"/soins-beaute","permanent":true},{"source":"/portfolio-subcategory/hydratant","destination":"/soins-beaute/soins-hydratants","permanent":true},{"source":"/portfolio-subcategory/peaux-seches","destination":"/soins-beaute/soins-hydratants","permanent":true},{"source":"/portfolio-subcategory/soins-anti-acneiques","destination":"/soins-beaute/soins-anti-imperfections","permanent":true},{"source":"/portfolio-subcategory/peaux-grasses-et-acneiques","destination":"/soins-beaute/soins-anti-imperfections","permanent":true},{"source":"/portfolio-subcategory/nettoyants","destination":"/soins-beaute/soins-nettoyants","permanent":true},{"source":"/portfolio-subcategory/taches-brunes","destination":"/soins-beaute/soins-taches-brunes","permanent":true},{"source":"/portfolio-subcategory/dermites-seborrheique","destination":"/soins-beaute/soins-capilaires/dermatite-seborrheique-soins-capilaires","permanent":true},{"source":"/portfolio-subcategory/aphtes","destination":"/soins-beaute/soins-reparateurs/aphtes","permanent":true},{"source":"/portfolio-subcategory/soins-cicatrisants","destination":"/soins-beaute/soins-reparateurs","permanent":true},{"source":"/portfolio-subcategory/cicatrices-hypertrophiques-et-cheloides","destination":"/soins-beaute/soins-reparateurs","permanent":true},{"source":"/portfolio-subcategory/vergetures","destination":"/soins-beaute/soins-reparateurs","permanent":true},{"source":"/portfolio-subcategory/peau-sensible","destination":"/soins-beaute","permanent":true},{"source":"/portfolio-subcategory/anti-ages-","destination":"/soins-beaute/soins-anti-age","permanent":true},{"source":"/portfolio-subcategory/poux","destination":"/produits/vamousse-traitement","permanent":true},{"source":"/portfolio-subcategory/solaires","destination":"/soins-beaute/protection-solaire","permanent":true},{"source":"/portfolio-category/aromatherapie","destination":"/soins-beaute/lithotherapie-et-aromatherapie","permanent":true},{"source":"/portfolio-category/lithotherapie","destination":"/soins-beaute/lithotherapie-et-aromatherapie","permanent":true},{"source":"/portfolio-subcategory/huiles-essentielles-","destination":"/soins-beaute/lithotherapie-et-aromatherapie/huiles-essentielles","permanent":true},{"source":"/portfolio-subcategory/huiles-vegetales","destination":"/soins-beaute/lithotherapie-aromatherapie/huiles-vegetales","permanent":true},{"source":"/portfolio-category/lithotherapie","destination":"/soins-beaute/lithotherapie-aromatherapie/lithotherapie","permanent":true},{"source":"/portfolio-subcategory/nos-bracelets-de-pierres-naturelles","destination":"/soins-beaute/lithotherapie-aromatherapie/lithotherapie","permanent":true},{"source":"/portfolio-category/maternite-et-bebe","destination":"/bebe-maternite","permanent":true},{"source":"/portfolio-subcategory/grossesse","destination":"/bebe-maternite/sante-de-la-mere","permanent":true},{"source":"/portfolio-subcategory/maternite","destination":"/bebe-maternite/sante-de-la-mere","permanent":true},{"source":"/portfolio-subcategory/sante-de-bebe","destination":"/bebe-maternite/mon-bebe","permanent":true},{"source":"/portfolio-subcategory/laits","destination":"/bebe-maternite/mon-bebe","permanent":true},{"source":"/portfolio-subcategory/peaux-alterees-","destination":"/soins-beaute/soins-reparateurs","permanent":true},{"source":"/portfolio-subcategory/nutritif","destination":"/soins-beaute/soins-hydratants","permanent":true},{"source":"/portfolio-subcategory/cc-creme","destination":"/soins-beaute/soins-anti-imperfections","permanent":true},{"source":"/portfolio-category/lunettes","destination":"/produits","permanent":true},{"source":"/portfolio/fluide-matifiant-jour","destination":"/produits/fluide-matifiant-jour","permanent":true},{"source":"/portfolio/revlon-lu-lec-fem-e1583202-","destination":"/produits","permanent":true},{"source":"/portfolio/solvityl-sirop","destination":"/produits/solyne-solvityl-sirop","permanent":true},{"source":"/portfolio/revlon-lu-lec-fem-e15745t-","destination":"/produits","permanent":true},{"source":"/portfolio/bronchonet-sans-sucre","destination":"/produits/phytopharm-bronchonet-sans-sucre","permanent":true},{"source":"/portfolio/magni-lu-lec-fem-p1581901v-","destination":"/produits","permanent":true},{"source":"/portfolio/phyveine-marron-d-inde","destination":"/produits/phytopharm-phyveine","permanent":true},{"source":"/portfolio/tisane-sante-vie-lactation","destination":"/produits/tisane-lactation-bio","permanent":true},{"source":"/portfolio/pack-bracelets-de-lithotherapie","destination":"/soins-beaute/lithotherapie-et-aromatherapie","permanent":true},{"source":"/portfolio/bracelet-a-pierres-hematite","destination":"/produits/bracelet-hematite","permanent":true},{"source":"/portfolio/oxyplastine-pommade","destination":"/produits/phytopharm-oxyplastine-pommade","permanent":true},{"source":"/portfolio/papulex-lotion","destination":"/produits/papulex-lotion","permanent":true},{"source":"/portfolio/calmiderm-","destination":"/produits/calmiderm-creme","permanent":true},{"source":"/portfolio/huile-essentielle-de-ravintsara","destination":"/produits/ravintsara","permanent":true},{"source":"/portfolio/gommage-douceur-visage","destination":"/produits/gommage-douceur","permanent":true},{"source":"/portfolio/revlon-solar-fem-e999502","destination":"/produits","permanent":true},{"source":"/portfolio/la-express-solare-hommes-b312602","destination":"/produits","permanent":true},{"source":"/portfolio/bio-taches-serum-30-ml","destination":"/produits/bio-taches-serum","permanent":true},{"source":"/portfolio/bronchonet-pastilles-gout-citron-miel","destination":"/produits/bronchonet-pastilles-citron-miel","permanent":true},{"source":"/portfolio/phylait","destination":"/produits/phylait","permanent":true},{"source":"/portfolio/tisane-sante-vie-sommeil","destination":"/produits/tisane-sante-vie-sommeil","permanent":true},{"source":"/portfolio/novalac-1er-age-400gr","destination":"/produits/phylait","permanent":true},{"source":"/portfolio/effadiane-baume-500ml","destination":"/produits/effadiane-topidian-baume","permanent":true},{"source":"/portfolio/magni-lu-lec-fem-p1582301v-","destination":"/produits","permanent":true},{"source":"/portfolio/bio-taches-solaire","destination":"/produits/bio-taches-creme-solaire","permanent":true},{"source":"/portfolio/bronchonet-pastilles-gout-menthe","destination":"/produits/bronchonet-pastilles-menthe","permanent":true},{"source":"/portfolio/effadiane-creme-tube-30ml","destination":"/produits/effadiane-creme-tube","permanent":true},{"source":"/portfolio/secoplast-pansements","destination":"/produits","permanent":true},{"source":"/portfolio/novalac-transit-1-400gr","destination":"/produits/novalac-transit-1-2-age","permanent":true},{"source":"/portfolio/atopiclair","destination":"/produits/atopiclair-creme","permanent":true},{"source":"/portfolio/creme-fondante-mains-et-ongles","destination":"/produits/creme-fondante-mains-et-ongles","permanent":true},{"source":"/portfolio/novalac-ac2-calinova-400gr","destination":"/produits/novalac-ac2-calinova-400gr","permanent":true},{"source":"/portfolio/huile-essentielle-de-citronnelle","destination":"/produits/citronelle","permanent":true},{"source":"/portfolio/bracelet-a-pierres-aventurine","destination":"/produits/bracelet-aventurine","permanent":true},{"source":"/portfolio/dolorol","destination":"/produits/dolorol","permanent":true},{"source":"/portfolio/bronchonet-pastilles-gout-orange","destination":"/produits/phytopharm-bronchonet-pastilles-orange","permanent":true},{"source":"/portfolio/cc-creme-tres-claire","destination":"/produits/cc-creme-extreme-perfection","permanent":true},{"source":"/portfolio/topicrem-eaumicellaire-douceur-","destination":"/produits/eau-micellaire-douceur","permanent":true},{"source":"/portfolio/revlon-lu-lec-fem-e15572-","destination":"/produits","permanent":true},{"source":"/portfolio/huile-essentielle-de-l-eucalyptus-citronne","destination":"/produits/eucalyptus-citronne","permanent":true},{"source":"/portfolio/novalac-allernova-400gr","destination":"/produits/novalac-alernova","permanent":true},{"source":"/portfolio/novalac-prema","destination":"/produits","permanent":true},{"source":"/portfolio/magni-lu-lec-fem-p1583602t-","destination":"/produits","permanent":true},{"source":"/portfolio/novalac-3eme-age-400gr","destination":"/produits/novalac-croissance-3eme-age","permanent":true},{"source":"/portfolio/papulex-uv-50ml","destination":"/produits/papulex-uv-50ml","permanent":true},{"source":"/portfolio/vamousse","destination":"/produits/vamousse-traitement","permanent":true},{"source":"/portfolio/sebclair-creme-30ml","destination":"/produits/sebclair-creme-sans-steroide","permanent":true},{"source":"/portfolio/bio-taches-solaire-invisible","destination":"/produits/bio-taches-creme-solaire-invisible","permanent":true},{"source":"/portfolio/bio-taches-masque","destination":"/produits/bio-taches-masque","permanent":true},{"source":"/portfolio/emulsion-legere","destination":"/produits/ona-hydratant-emulsion-legere","permanent":true},{"source":"/portfolio/lait-hydratant","destination":"/produits/lavande-officinale","permanent":true},{"source":"/portfolio/huile-essentielle-de-la-lavande-officinale","destination":"/produits/huile-essentielle-de-la-lavande-officinale","permanent":true},{"source":"/portfolio/papulex-creme-oil-free-","destination":"/produits/papulex-creme-oil-free","permanent":true},{"source":"/portfolio/solvityl-gumiz-multivitamines","destination":"/marques/solyne","permanent":true},{"source":"/portfolio/creme-reparatrice","destination":"/produits/soin-cicatrisant-creme-reparatrice","permanent":true},{"source":"/portfolio/huile-essentielle-de-l-eucalyptus-globuleux","destination":"/produits/eucalyptus-globuleux","permanent":true},{"source":"/portfolio/bronchonet-baume","destination":"/produits/phytopharm-bronchonet-baume","permanent":true},{"source":"/portfolio/solyne-vitamine-c-500","destination":"/produits/solyne-vitamine-c","permanent":true},{"source":"/portfolio/gelee-nettoyante-gommante","destination":"/produits/gelee-nettoyante-gommante","permanent":true},{"source":"/portfolio/vomiteb-sirop","destination":"/produits/phytopharm-vomiteb","permanent":true},{"source":"/portfolio/bracelet-a-pierres-cornaline","destination":"/produits/bracelet-cornaline","permanent":true},{"source":"/portfolio/secoplast-pansements-transparents","destination":"/marques/seco","permanent":true},{"source":"/portfolio/tisane-sante-vie-digestion-difficile","destination":"/produits/sante-vie-tisane-digestion","permanent":true},{"source":"/portfolio/huile-essentielle-de-ylang-ylang","destination":"/produits/ylang-ylang","permanent":true},{"source":"/portfolio/la-express-solare-fem-b263102","destination":"/produits","permanent":true},{"source":"/portfolio/la-express-solare-hommes-b314201","destination":"/produits/la-express-solare-hommes-b314201","permanent":true},{"source":"/portfolio/huile-vegetale-de-graines-de-ricin","destination":"/produits","permanent":true},{"source":"/portfolio/baume-fondant-nutritif","destination":"/marques/onagrine","permanent":true},{"source":"/portfolio/magnivision-lu-lec-fem-p15807-","destination":"/produits","permanent":true},{"source":"/portfolio/tisane-sante-vie-diabete","destination":"/produits/sante-vie-diabete","permanent":true},{"source":"/portfolio/phyriane","destination":"/marques/sante-bien-etre/bien-etre/troubles-du-sommeil-et-reveil-nocturne","permanent":true},{"source":"/portfolio/appeti-kid-sirop","destination":"/produits/phytopharm-apeti-kid","permanent":true},{"source":"/portfolio/tisane-sante-vie-regles-douloureuses","destination":"/produits/tisane-regles-douloureuses","permanent":true},{"source":"/portfolio/la-express-solare-hommes-b440801","destination":"/produits","permanent":true},{"source":"/portfolio/tisane-sante-vie-gaz-colon","destination":"/produits/tisane-gaz-colon","permanent":true},{"source":"/portfolio/huile-vegetale-de-graines-de-jojoba","destination":"/produits/huile-graines-jojoba","permanent":true},{"source":"/portfolio/kelo-stretch-creme-125ml","destination":"/produits/kelo-stretch-creme-anti-vergetures","permanent":true},{"source":"/portfolio/masque-hydratation-intense","destination":"/produits/ona-hydratant-masque-hydratation-intense","permanent":true},{"source":"/portfolio/diffuseur-d-aromatherapie-“lumiere-et-ombre”","destination":"/produits/diffuseur-des-huiles-essentielles","permanent":true},{"source":"/portfolio/magnivision-lu-lec-us-p15257-","destination":"/produits","permanent":true},{"source":"/portfolio/solyne-magnesium-300-mg","destination":"/produits/solyne-magnesium-300-mg","permanent":true},{"source":"/portfolio/huile-essentielle-petit-grain-bigaradier","destination":"/produits/petit-grain-bigaradier","permanent":true},{"source":"/portfolio/bronchonet-sirop","destination":"/produits/phytopharm-bronchonet-sirop","permanent":true},{"source":"/portfolio/hemorrol","destination":"/produits/phytopharm-hemorrol","permanent":true},{"source":"/portfolio/bio-taches-emulsion","destination":"/produits/bio-taches-emulsion","permanent":true},{"source":"/portfolio/huile-vegetale-de-graines-de-nigelle","destination":"/produits/nigelle","permanent":true},{"source":"/portfolio/gel-contour-des-yeux","destination":"/produits/lca-contour-des-yeux","permanent":true},{"source":"/portfolio/masque-depigmentant","destination":"/produits/masque-depigmentant","permanent":true},{"source":"/portfolio/sebclair-shampoo-100ml","destination":"/produits/sebclair-shampoo","permanent":true},{"source":"/portfolio/huile-essentielle-de-l-arbre-a-the","destination":"/produits/arbre-a-the","permanent":true},{"source":"/portfolio/bracelet-pierre-de-lune","destination":"/produits/bracelet-pierre-de-lune","permanent":true},{"source":"/portfolio/tisane-sante-vie-constipation","destination":"/produits/tisane-constipation","permanent":true},{"source":"/portfolio/serum-creme-lissant-eclat","destination":"/produits/serum-creme-lissant-eclat","permanent":true},{"source":"/portfolio/dolopatch-anti-douleur","destination":"/produits/dolopatch-antidouleur","permanent":true},{"source":"/portfolio/novalac-diarinova-250-gr","destination":"/marques/novalac","permanent":true},{"source":"/portfolio/la-express-solare-hommes-b314004","destination":"/produits","permanent":true},{"source":"/portfolio/magnivision-lu-lec-us-p15590-","destination":"/produits","permanent":true},{"source":"/portfolio/test-d-ovulation","destination":"/produits","permanent":true},{"source":"/portfolio/aloclair-plus-gel-8ml","destination":"/produits/aloclair-plus-gel","permanent":true},{"source":"/portfolio/huile-essentielle-de-girofle","destination":"/produits/girofle","permanent":true},{"source":"/portfolio/macerat-huileux-de-petales-de-rose","destination":"/produits/macerat-de-rose","permanent":true},{"source":"/portfolio/solyne-grossesse","destination":"/produits/solyne-grossesse","permanent":true},{"source":"/portfolio/tisane-sante-vie-bouffees-de-chaleur","destination":"/produits/bouffees-de-chaleur","permanent":true},{"source":"/portfolio/kelo-cote-6-gr","destination":"/produits/kelo-cote-gel","permanent":true},{"source":"/portfolio/novalac-transit-2-400-gr","destination":"/produits/novalac-transit-1-2-age","permanent":true},{"source":"/portfolio/novalac-ac1-calinova-400gr","destination":"/marques/novalac","permanent":true},{"source":"/portfolio/dolopatch-capsicum","destination":"/produits/dolopatch-capsicum","permanent":true},{"source":"/portfolio/gel-lavant-surgras","destination":"/produits/gel-lavant-surgras","permanent":true},{"source":"/portfolio/la-express-solare-hommes-b312701t","destination":"/produits","permanent":true},{"source":"/portfolio/secoplast-pansements-a-decouper","destination":"/marques/seco","permanent":true},{"source":"/portfolio/magnivision-lu-lec-fem-p15833-","destination":"/produits","permanent":true},{"source":"/portfolio/papulex-isocorrection","destination":"/produits/papulex-isocorrection","permanent":true},{"source":"/portfolio/la-express-solare-hommes-b440601t","destination":"/produits","permanent":true},{"source":"/portfolio/huile-essentielle-de-geranium-bourbon","destination":"/produits/geranium-de-bourbon","permanent":true},{"source":"/portfolio/phystress","destination":"/produits/phytopharm-phystress","permanent":true},{"source":"/portfolio/magnivision-lu-lec-fem-p15809-","destination":"/produits","permanent":true},{"source":"/portfolio/kelo-cote-60-gr","destination":"/produits/kelo-cote-gel","permanent":true},{"source":"/portfolio/cc-creme-claire","destination":"/produits/cc-creme-extreme-perfection","permanent":true},{"source":"/portfolio/secoplast-sparadrap","destination":"/marques/seco","permanent":true},{"source":"/portfolio/contour-des-yeux","destination":"/produits/extreme-jeunesse-contour-des-yeux","permanent":true},{"source":"/portfolio/bracelet-a-pierres-lapis-lazuli","destination":"/produits/bracelet-lapis-lazuli","permanent":true},{"source":"/portfolio/tisane-sante-vie-minceur","destination":"/produits/tisane-minceur","permanent":true},{"source":"/portfolio/thymoseptine","destination":"/produits/phytopharm-thymospetine","permanent":true},{"source":"/portfolio/tisane-sante-vie-jambes-lourdes","destination":"/produits/tisane-jambes-lourdes","permanent":true},{"source":"/portfolio/la-express-solare-hommes-b263001","destination":"/produits","permanent":true},{"source":"/portfolio/phybaby","destination":"/produits/phybaby","permanent":true},{"source":"/portfolio/gelee-nettoyante-douceur","destination":"/produits/gelee-nettoyante-douceur-visage","permanent":true},{"source":"/portfolio/revlon-solar-fem-e998602","destination":"/produits","permanent":true},{"source":"/portfolio/magnivision-lu-lec-us-p15448-","destination":"/produits","permanent":true},{"source":"/portfolio/huile-essentielle-de-la-menthe-poivree","destination":"/produits/menthe-poivree","permanent":true},{"source":"/portfolio/magnivision-lu-lec-fem-p15808-","destination":"/produits","permanent":true},{"source":"/portfolio/magni-lu-lec-fem-p1581706-","destination":"/produits","permanent":true},{"source":"/portfolio/aroma-necklace-stainless-steel","destination":"/produits/aroma-necklace-stainless-steel","permanent":true},{"source":"/portfolio/huile-essentielle-de-gingembre","destination":"/produits/gingembre","permanent":true},{"source":"/portfolio/dolopatch-hydro-gel","destination":"/produits/dolopatch-hydrogel","permanent":true},{"source":"/portfolio/gel-nettoyant-purifiant","destination":"/produits/gel-nettoyant-purifiant","permanent":true},{"source":"/portfolio/la-express-solare-hommes-b313902","destination":"/produits","permanent":true},{"source":"/portfolio/novalac-ar1-400gr","destination":"/produits/novalac-ar1-age","permanent":true},{"source":"/portfolio/vomiteb-comprimes-b30","destination":"/produits/phytopharm-vomiteb-comprime","permanent":true},{"source":"/portfolio/secoplast-pansements-chair","destination":"/produits/secoplast-pansements-chair","permanent":true},{"source":"/portfolio/soin-des-levres","destination":"/marques/onagrine","permanent":true},{"source":"/portfolio/la-express-solare-hommes-b312702","destination":"/produits","permanent":true},{"source":"/portfolio/phytonus","destination":"/produits/phytopharm-phytonus","permanent":true},{"source":"/portfolio/magni-lu-lec-us-p1582001v-","destination":"/produits","permanent":true},{"source":"/portfolio/magnivision-lu-lec-us-p15233-","destination":"/produits","permanent":true},{"source":"/portfolio/creme-riche","destination":"/produits/ona-hydratant-creme-riche","permanent":true},{"source":"/portfolio/aromask","destination":"/marques/phytencia","permanent":true},{"source":"/portfolio/babydo-gouttes-60ml","destination":"/produits/phytopharm-baby-do","permanent":true},{"source":"/portfolio/test-de-grossesse","destination":"/marques/bebe-maternite/sante-de-la-mere","permanent":true},{"source":"/portfolio/toux-kid","destination":"/produits/phytopharm-toux-kid","permanent":true},{"source":"/portfolio/bronchonet-inhalateur","destination":"/produits/phytopharm-bronchonet-inhalateur","permanent":true},{"source":"/portfolio/l-arbre-de-vie","destination":"/produits/l-arbre-de-vie","permanent":true},{"source":"/portfolio/novalac-ar-digest-400gr","destination":"/produits/novalac-ar-digest","permanent":true},{"source":"/portfolio/geni-kid","destination":"/produits/geni-kid","permanent":true}]},
  })
  handler = nextServer.getRequestHandler()

  console.log(
    'Listening on port',
    currentPort,
    'url: http://' + hostname + ':' + currentPort
  )
})